django-laterpay
======================

.. image:: https://badge.fury.io/py/django-laterpay.png
    :target: http://badge.fury.io/py/django-laterpay

.. image:: https://travis-ci.org/laterpay/django-laterpay.png?branch=develop
    :target: https://travis-ci.org/laterpay/django-laterpay

.. image:: https://coveralls.io/repos/laterpay/django-laterpay/badge.png?branch=develop
    :target: https://coveralls.io/r/laterpay/django-laterpay

.. image:: https://pypip.in/d/django-laterpay/badge.png
    :target: https://crate.io/packages/django-laterpay?version=latest


`LaterPay <http://www.laterpay.net/>`__ Django utilities

Installation
------------

::

    $ pip install django-laterpay

Usage
-----

See https://www.laterpay.net/developers/docs

Development
-----------

See https://github.com/laterpay/django-laterpay

`Tested by Travis <https://travis-ci.org/laterpay/django-laterpay>`__
